@@ -38,6 +38,9 @@ class GQLInput(BaseModel):
                 elif type(val) is str:
                     s = f'{field_name}: "{val}"'
                     str_lst.append(s)
+                elif type(val) is bool:
+                    s = f'{field_name}: {"false" if val is False else "true"}'
+                    str_lst.append(s)
                 else:
                     s = f"{field_name}: {val}"
                     str_lst.append(s)
