@@ -10,8 +10,6 @@ from .node import Node, Params
 
 NodeType = T.TypeVar("NodeType", bound=Node)
 
-NodeTypeInner = T.TypeVar("NodeTypeInner", bound=Node)
-
 GetParamsType = T.TypeVar("GetParamsType", bound=Params)
 QueryParamsType = T.TypeVar("QueryParamsType", bound=Params)
 EdgesType = T.TypeVar("EdgesType", bound=BaseModel)
@@ -35,7 +33,8 @@ def get_fields_and_nested_fields(cls: T.Type[BaseModelType]) -> T.List[str]:
 
 
 class Resolver(BaseModel, T.Generic[NodeType]):
-    node: T.ClassVar[T.Type[NodeTypeInner]]
+    # node: T.ClassVar[T.Type[NodeType]]
+    node: T.ClassVar[T.Type[Node]]
 
     query_params: QueryParamsType
     edges: EdgesType
